/******************** (C) COPYRIGHT 2006 STMicroelectronics ********************
* File Name          : Init_Module.c
* Author             : MCD Application Team
* Date First Issued  : 08/12/06
* Description        : This file provides all C routines to initialize ADC,
*                      PWM and FIR for the filter's example 
********************************************************************************
* History:
* 08/12/2006 :  Version 1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "Init_Module.h"

/* Private variables ---------------------------------------------------------*/
/*16-bit FIR coefficients mapped in DPRAM ------------------------------------*/ 
iram short FIR_COEFF[NB_FIR_COEFF]= {-1402 , 
                                     -1605 , 
                                     -895  , 
                                      701  , 
                                      2956 , 
                                      5174 , 
                                      6898 , 
                                      7537 ,
                                      6898 , 
                                      5174 , 
                                      2956 , 
                                      701  , 
                                     -895  , 
                                     -1605 , 
                                     -1402 }; 


/*16-bit DELAY buffer defintion mapped in DPRAM -----------------------------*/
iram short DELAY_LINE[NB_FIR_COEFF]={0, 
                                     0,
                                     0,
                                     0,
                                     0,
                                     0,
                                     0,
                                     0,
                                     0, 
                                     0,
                                     0,
                                     0,
                                     0,
                                     0,
                                     0};

/*16-bit Inputs initi buffer ------------------------------------------------*/
iram short Inputs[NB_FIR_COEFF] =  {0, 
                                    0,
                                    0,
                                    0,
                                    0,
                                    0,
                                    0,
                                    0,
                                    0, 
                                    0,
                                    0,
                                    0,
                                    0,
                                    0,
                                    0};




/*******************************************************************************
* Function Name  : ADC_Init
* Description    : Initailzes the ADC module
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/
void ADC_Init( void )
{
 /* Channel 0 Selection, Fixed channed single conversion, ADWR wait mode */
 /* conversion time set up */
   ADCCON = 0x0200;					   
}


/*******************************************************************************
* Function Name  : PWM_Init
* Description    : Initailzes the PWM module which is used as 8-bit DAC
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/
void PWM_Channel0_Init( void )
{
  /* PWMCON1 Intialization : PWM0 output disabled, edge aligned mode */
   PWMCON1 = 0x0000;

  /* PWMCON0 Intialization : PWM0 IT Enable, PWM clocked with FCPU  */
   PWMCON0 = 0x0100;
 
  /*  P7.0 Output Direction selection */
   DP7 |= 0x0001;

  /* Configure the PP0 register */
   PP0 = 0x00FF; 

  /* Configure the PW0 register */	
   PW0 = PP0 + 1;
  
  /* Start PWM0 timer running */				
   PTR0 = 1; 		
}	  

/*******************************************************************************
* Function Name  : FIR_Init
* Description    : Initailzes a filter structure with the following paramters
*                : Filter's number of coeff = NB_FIR_COEFF
*                : One output sample computed 
*                : Table of coeff's coeff = FIR_COEFF 
*                : Number of input samples = NB_FIR_COEFF 
* Input          : Pointer on a Filter structure .
* Output         : None.
* Return         : None.
*******************************************************************************/
void FIR_Init( struct Filter _iram *fir)
{	
  /* Filter Structure Initialization */
  /* Filter coefficients' number */		
  fir->NumberCoeffs = NB_FIR_COEFF;

  /* Filter Output Samples number */
  fir->NumberOutputSamples = NB_OUTPUT;

  /* Filter Coefficients array */	
  fir->CoeffPtr = FIR_COEFF;

  /* Filter Delay */
  fir->DelayLinePtr = DELAY_LINE;

  /* Filter Input samples array */	
  fir->InputPtr = Inputs;			
}

/************************ (c) 2006  ST Microelectronics ******* END OF FILE ***/




 

 