/************************************************************************
;
;   File       : LibST10.h
;   Creator    : Arnaud SANIAL
;   Date       : january 2002
;   Comment    : This file is the header file for st10 dsp library
;
;
;***********************************************************************/


/* ADDITION */

extern void add_16 (short LeftOp, short RightOp, short near *Output);

extern void add_32 (short LeftOpMsb, short LeftOpLsb, short RightOpMsb, short RightOpLsb ,
 				long near *Output);

extern void  cAdd_16 (short LeftOp_I, short LeftOp_R, short RightOp_I, short RightOp_R ,
 				long near *Output);

extern void  cAdd_32 (short LeftOpMsb_I, short LeftOpLsb_I, short LeftOpMsb_R, short LeftOpLsb_R,
                       short RightOpMsb_I, short RightOpLsb_I, short RightOpMsb_R , short RightOpMsb_I,
 				long near *Output);




/* SUBSTRACTION */

extern void sub_16 (short LeftOp, short RightOp, short near *Output);

extern void sub_32 (short LeftOpMsb, short LeftOpLsb, short RightOpMsb, short RightOpLsb ,
 				long near *Output);

extern void cSub_16 (short LeftOp_I, short LeftOp_R, short RightOp_I, short RightOp_R ,
 				long near *Output);

extern void cSub_32 (short LeftOpMsb_I, short LeftOpLsb_I, short LeftOpMsb_R, short LeftOpLsb_R,
                      short RightOpMsb_I, short RightOpLsb_I, short RightOpMsb_R , short RightOpMsb_I,
 		   	long near *Output);


/* MULTIPLICATION  */

extern void mul_q15_q15_q31 (short LeftOp, short RightOp, long near *Output);

extern void mul_q31_q31_q31 (short LeftOpMsb, short LeftOpLsb, short RightOpMsb, short RightOpLsb, long near *Output);

extern void cMul_q15_q15_q15 (short LeftOp_I, short LeftOp_R, short RightOp_I, short RightOp_R, short near *Output);

extern void cMul_q31_q31_q31(short Op1_I_Msb, short Op1_I_Lsb, short Op1_R_Msb, short Op1_R_Lsb, 
	             short Op2_I_Msb, short Op2_I_Lsb, short Op2_R_Msb, short Op2_R_Lsb, long near *Output);


/* DIVISION */


extern void div_q31_q15_q15 (short LeftOpMsb, short LeftOpLsb, short RightOp, short near *Output);

extern void div_q63_q31_q31(short LeftOpMsb, short LeftOp2b,  short LeftOp3b, short LeftOpLsb,
		     short RightOpMsb, short RightOpLsb, long near *Output);

extern void cDiv_q31_q15_q15 (short LeftOpIMsb, short LeftOpILsb, short LeftOpRMsb, short LeftOpRLsb,
		      short RightOpI, short RightOpR, short near *Output);

extern void cDiv_q31 (short LeftOpIMsb, short LeftOpILsb, short LeftOpRMsb, short LeftOpRLsb,
		      short RightOpIMsb, short RightOpILsb, short RightOpRMsb, short RightOpRLsb,
		      long near *Output);



/* SQUARE ROOT  */

extern void sqrt_p16q16_p8q8 (short xmsb, short xlsb, short near *y);



/* FIR */

// FIR structure definition 
typedef struct Filter
{
	/* coefficients pointer */
	short _iram *CoeffPtr;

	/* Number of coefficients of the filter */
	/* Examples :
	   .Fir: 
	   y(n)=a0*x(n)+a1*x(n-1)+...+a15*x(n-15)
	   Store NumberCoeffs=16

	   .Iir direct form
	   y(n)=b0*x(n)+b1*x(n-1)+...+b15*x(n-15)+a1*y(n-1)+...+a15*y(n-15)
	   Store NumberCoeffs=32   (a0=0 is stored in memory)

	   .Iir iirBiquad5_q15_q15_q15 form
	   y(n)=b00*x(n)+...+a02*y(n-2)+.....+a92*y(n-2)
	   !!!!!!Store NumberCoeffs = NumberCells = 10 !!!!!!!!
	*/	  
	short NumberCoeffs;

	/* Input samples pointer */		  
	short near *InputPtr;

	/* Output samples pointer */		  
	short near *OutputPtr;

	/* Number of output samples to compute */ 
	short NumberOutputSamples;

	/* Delay line base address */  	  	  
	/* the size of the delay line is egal to order */
 	short _iram *DelayLinePtr;		

} ;



void fir_q15_q15_q15(struct Filter _iram *FirPtr);

void fir_q15_q31_q15(struct Filter _iram *FirPtr);

void fir_q31_q31_q31(struct Filter _iram *FirPtr);


/* IIR FILTER    */

void iir2_q15_q15_q15(struct Filter _iram *IirPtr);


void iirBiquad5_q15_q15_q15(struct Filter _iram *IirPtr);


/* MATRIX   */

void mMul_q15_q15_q15(short _iram Mat1[][], int row1, int column1, short _iram Mat2[][], 
					int column2, short near Matres[][]);

void mVM_q15_q15_q15(short _iram Mat[][], short near *Vectin, int n, short _iram *Vectres);

